cibuildwheel: Build Python wheels on CI with minimal configuration
==================================================================

Description
-----------

Build Python wheels on CI with minimal configuration

License
-------

Upstream Contact
----------------

https://pypi.org/project/cibuildwheel/

